==> billogram-foundation-2.4.0.tgz: package/modules/components/component/component.js <==
import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import invariant from 'invariant';

import mount from './redux-actions/mount';
import unmount from './redux-actions/unmount';

import isNullOrEmpty from '../../isNullOrEmpty';


export default (Component, {
    initialComponentState,
    initialize = null,
    root
} = {}) => {

    invariant(Component !== undefined, 'Missing Component');
    invariant(!isNullOrEmpty(root), 'Missing root.');

    const Container = React.createClass({

        displayName: `component(${Component.displayName})`,

        propTypes: {
            initialized: PropTypes.bool.isRequired,
            onMount: PropTypes.func.isRequired,
            onUnmount: PropTypes.func.isRequired,
            // ---
            component: PropTypes.object
        },

        componentDidMount() {
            this.props.onMount();
        },

        componentWillUnmount() {
            this.props.onUnmount();
        },

        render() {
            const {
                initialized,
                onMount,        // eslint-disable-line no-unused-vars
                onUnmount,      // eslint-disable-line no-unused-vars
                component,
                ...rest
            } = this.props;

            if (!initialized) {
                return null;
            }

            return (
                <Component
                    { ...rest }
                    component={ component }
                    root={ root } />
            );
        }

    });

    const mapStateToProps = (state) => {
        const component = state.components[root];
        return {
            component,
            initialized: component !== undefined
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        return {
            onMount: () => {
                dispatch(mount({ initialComponentState, root }));

                if (initialize !== null) {
                    dispatch(initialize({ props, root }));
                }
            },
            onUnmount: () => dispatch(unmount({ root }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};

==> billogram-foundation-2.6.1.tgz: package/modules/components/component/component.js <==
import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import invariant from 'invariant';

import mount from './redux-actions/mount';
import unmount from './redux-actions/unmount';

import isNullOrEmpty from '../../isNullOrEmpty';


export default (Component, {
    initialComponentState,
    initialize = null,
    root
} = {}) => {

    invariant(Component !== undefined, 'Missing Component');
    invariant(!isNullOrEmpty(root), 'Missing root.');

    const Container = React.createClass({

        displayName: `Component(${Component.displayName})`,

        propTypes: {
            initialized: PropTypes.bool.isRequired,
            onMount: PropTypes.func.isRequired,
            onUnmount: PropTypes.func.isRequired,
            // ---
            component: PropTypes.object
        },

        componentDidMount() {
            this.props.onMount();
        },

        componentWillUnmount() {
            this.props.onUnmount();
        },

        render() {
            const {
                initialized,
                onMount,        // eslint-disable-line no-unused-vars
                onUnmount,      // eslint-disable-line no-unused-vars
                component,
                ...rest
            } = this.props;

            if (!initialized) {
                return null;
            }

            return (
                <Component
                    { ...rest }
                    component={ component }
                    root={ root } />
            );
        }

    });

    const mapStateToProps = (state) => {
        const component = state.components[root];
        return {
            component,
            initialized: component !== undefined
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        return {
            onMount: () => {
                dispatch(mount({ initialComponentState, root }));

                if (initialize !== null) {
                    dispatch(initialize({ props, root }));
                }
            },
            onUnmount: () => dispatch(unmount({ root }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};
